Changes
=======

Version 0.3.0 (2018-08-10)
--------------------------

- This package is a result of refactoring _`<https://reana-commons.readthedocs.io/>`.
- Provides common REANA models.
- Provides database connection logic.

.. admonition:: Please beware

   Please note that REANA is in an early alpha stage of its development. The
   developer preview releases are meant for early adopters and testers. Please
   don't rely on released versions for any production purposes yet.
